@@ -6,32 +6,36 @@ This file is part of the ParticleOne and is released under the "MIT". Please
 see the license.txt file that should have been included as part of this
 package.
 
-
-Import as
-
+Import as:
 import p1_data_client_python.client as p1_data
 """
 
 import json
+import os
 from typing import Any, Dict, List
 
 import pandas as pd
 import requests
 
+import helpers.datetime_ as hdatet
 import p1_data_client_python.abstract_client as p1_abs
 import p1_data_client_python.exceptions as p1_exc
 
+P1_DATA_API_VERSION = os.environ.get("P1_DATA_API_VERSION", "1")
+
 
 class Client(p1_abs.AbstractClient):
     """Class for p1 data REST API operating."""
 
     SEARCH_CHUNK_SIZE = 1000
 
+    _URL = f"/data-api/v{P1_DATA_API_VERSION}"
+
     METADATA_ROUTES = {
-        "COMMODITIES": "/data-api/v1/commodities/",
-        "BUSINESS-CATEGORIES": "/data-api/v1/business-categories/",
-        "COUNTRIES": "/data-api/v1/countries/",
-        "FREQUENCIES": "/data-api/v1/frequencies/",
+        "COMMODITIES": _URL + "/commodities/",
+        "BUSINESS-CATEGORIES": _URL + "/business-categories/",
+        "COUNTRIES": _URL + "/countries/",
+        "FREQUENCIES": _URL + "/frequencies/",
     }
 
     @property
@@ -47,7 +51,6 @@ class Client(p1_abs.AbstractClient):
         """
         current_page_number = 1
         row_count = self._last_total_count
-
         if self._scroll_id:
             while True:
                 if row_count > 0 and current_page_number < pages_limit:
@@ -60,7 +63,7 @@ class Client(p1_abs.AbstractClient):
                 current_page_number += 1
 
     def search_scroll(self) -> Dict[Any, Any]:
-        """Get next chunk(page) of payloads by given scroll_id."""
+        """Get next chunk (page) of payloads by given scroll_id."""
         response = self._make_request(
             "GET",
             self.base_url + self._api_routes["SEARCH_SCROLL"],
@@ -78,7 +81,7 @@ class Client(p1_abs.AbstractClient):
             )
         return next_page
 
-    def search(self, **search_payload) -> pd.DataFrame:
+    def search(self, **search_payload: Any) -> pd.DataFrame:
         """Get payloads IDs by given search conditions.
 
         :param text:
@@ -173,14 +176,15 @@ class Client(p1_abs.AbstractClient):
         payloads = response.json()
         self._scroll_id = payloads["scroll_id"]
         self._last_total_count = payloads["total_count"]
-
         return pd.DataFrame(payloads["rows"])
 
     @staticmethod
     def _parse_payload(response: requests.Response) -> pd.DataFrame:
         """Parse payload response and return pandas Dataframe."""
         payload_response = response.json()
-        return pd.DataFrame(payload_response["payload_data"])
+        payload = pd.DataFrame(payload_response["payload_data"])
+        payload["period"] = hdatet.to_datetime(payload["original_period"])
+        return payload
 
     @staticmethod
     def _parse_metadata_type(
@@ -189,4 +193,4 @@ class Client(p1_abs.AbstractClient):
         """Parse metadata_type response and return pandas Dataframe."""
         metadata_response = response.json()
         metadata_list = [row["name"] for row in metadata_response["data"]]
-        return pd.DataFrame(metadata_list, columns=[metadata_type])
\ No newline at end of file
+        return pd.DataFrame(metadata_list, columns=[metadata_type])
